@@ -1,7 +1,7 @@
       implicit none
-c
-c         compute pair total xs.  prob/r.l, prob/(g/cm2), prob/cm , mb/atom
-c
+!
+!         compute pair total xs.  prob/r.l, prob/(g/cm2), prob/cm , mb/atom
+!
 #include "Zglobalc.h"
 #include "ZbasicCnst.h"
 #include "Zmedia.h"
@@ -34,13 +34,13 @@ c
 
          write(*,*) "#  'prob.  of Pair Creation'"
          write(*,*) 
-     *   "#  'Eg(MeV)'  ' /r.l' '/(g/cm2)' '/cm' 'mb/atom'"
+     *   "#  'Eg(MeV)'  ' /r%l' '/(g/cm2)' '/cm' 'mb/atom'"
          Eg = 2.2*masele
          do while ( Eg .lt. Egmax)   
             call epPrSampP(media, Eg, tprob, p)
             write(*, *) sngl(Eg*1000.d0), 
-     *       sngl(tprob), sngl(tprob/media.X0g),
-     *       sngl(tprob/media.X0), sngl(tprob/media.mbtoPX0)
+     *       sngl(tprob), sngl(tprob/media%X0g),
+     *       sngl(tprob/media%X0), sngl(tprob/media%mbtoPX0)
             Eg = Eg * 10.0d0**(0.025d0)
          enddo
       else
