@@ -14,6 +14,8 @@ subroutine epLightNoOfSurf(cn, nsurf)
       
   if(struc(1:3) == "box") then
      nsurf = 6
+  elseif(struc(1:7) == "octagon" ) then
+     nsurf = 10
   elseif(struc(1:3) == "cyl") then
      nsurf = 3
   elseif(struc(1:4) == "ecyl") then
