@@ -119,6 +119,50 @@
                   call arprmc(vvalue, MCSdir)
                elseif( vname == 'MCSparam' ) then
                   call arprmc(vvalue, MCSparam)
+!             elseif( vname == 'MCSxRange' ) then
+!                  if(MCSxCond < MCSxyzCondmx) then
+!                     MCSxCond = MCSxCond+1
+!                     call arprmm(vvalue, MCSxRange(MCSxCond))
+!                  else
+!                     write(0,*) ' too many MCSxRange'
+!                     stop
+!                  endif
+                  
+!                  if(MCSyCond < MCSxyzCondmx) then
+!                     MCSyCond = MCSyCond+1
+!                     call arprmm(vvalue, MCSyRange(MCSyCond))
+!                  else
+!                     write(0,*) ' too many MCSyRange'
+!                     stop
+!                  endif
+             elseif( vname == 'MCSzRange' ) then
+                  if(MCSzCond < MCSxyzCondmx) then
+                     MCSzCond = MCSzCond+1
+                     call arprmm(vvalue, MCSzRange(MCSzCond))
+                  else
+                     write(0,*) ' too many MCSzRange'
+                     stop
+                  endif
+                  
+               elseif( vname == 'MCSnumRange' ) then
+                  if(MCSnumCond < MCSnumCondmx) then
+                     MCSnumCond = MCSnumCond+1
+                     call arprmm(vvalue, MCSnumRange(MCSnumCond))
+                  else
+                     write(0,*) ' too many MCSnumRange'
+                     stop
+                  endif
+               elseif( vname == 'MCSandor' ) then
+                  call arprmc(vvalue, MCSandor )
+                  if( MCSandor /= 'and' .and. MCSandor /= 'or' ) then
+                     write(0,*) ' MCSandor value =',MCSandor
+                     write(0,*) ' invalid. '
+                     stop
+                  endif
+               elseif( vname == 'MCSrevert' ) then
+                  call arprml(vvalue, MCSrevert)
+               elseif( vname == 'MCSdebug' ) then
+                  call arprml(vvalue, MCSdebug)
                elseif( vname == 'sbMin' ) then ! v9.201;don't use
                   write(0,*)
      *            'NOTE****: sbMin in epicsfile obsolete; not used'
